@@ -5,10 +5,10 @@
 extern "C" {
 #endif
 
-#include <stdio.h>
-#include <stdlib.h>
 #include "cones.h"
 #include "scs.h"
+#include <stdio.h>
+#include <stdlib.h>
 
 /* timing code courtesy of A. Domahidi */
 #if (defined NOTIMER)
@@ -41,23 +41,11 @@ typedef struct SCS(timer) {
 
 #endif
 
-#if EXTRA_VERBOSE > 1
-extern SCS(timer) global_timer;
-#endif
-
 /* these all return milli-seconds */
 void SCS(tic)(SCS(timer) * t);
-scs_float SCS(toc)(SCS(timer) * t);
-scs_float SCS(str_toc)(char *str, SCS(timer) * t);
 scs_float SCS(tocq)(SCS(timer) * t);
-
-void SCS(print_cone_data)(const ScsCone *k);
-void SCS(print_data)(const ScsData *d);
-void SCS(print_work)(const ScsWork *w);
-void SCS(print_array)(const scs_float *arr, scs_int n, const char *name);
-void SCS(set_default_settings)(ScsData *d);
 void SCS(free_sol)(ScsSolution *sol);
-void SCS(free_data)(ScsData *d, ScsCone *k);
+void SCS(free_data)(ScsData *d, ScsCone *k, ScsSettings *stgs);
 
 #ifdef __cplusplus
 }
